@@ -19,6 +19,8 @@ class RiskTags(object):
 
 
 class DetectionListsClient(object):
+    """`Rest documentation <https://developer.code42.com/api/#tag/Detection-Lists>`__"""
+
     def __init__(
         self,
         user_profile_service,
@@ -39,6 +41,7 @@ class DetectionListsClient(object):
 
     def create_user(self, username):
         """Create a detection list profile for a user.
+        `Rest Documentation <https://developer.code42.com/api/#operation/UserControllerV2_Create>`__
 
         Args:
             username (str): The Code42 username of the user.
@@ -50,6 +53,7 @@ class DetectionListsClient(object):
 
     def get_user(self, username):
         """Get user details by username.
+        `Rest Documentation <https://developer.code42.com/api/#operation/UserControllerV2_GetByUsername>`__
 
         Args:
             username (str): The Code42 username of the user.
@@ -61,6 +65,7 @@ class DetectionListsClient(object):
 
     def get_user_by_id(self, user_id):
         """Get user details by user_id.
+        `Rest Documentation <https://developer.code42.com/api/#operation/UserControllerV2_GetByUserId>`__
 
         Args:
             user_id (str or int): The Code42 userId of the user.
@@ -72,6 +77,7 @@ class DetectionListsClient(object):
 
     def update_user_notes(self, user_id, notes):
         """Add or update notes related to the user.
+        `Rest Documentation <https://developer.code42.com/api/#operation/UserControllerV2_UpdateNotes>`__
 
         Args:
             user_id (str or int): The userUid of the user whose notes you want to update.
@@ -84,6 +90,7 @@ class DetectionListsClient(object):
 
     def add_user_risk_tags(self, user_id, tags):
         """Add one or more risk factor tags.
+        `Rest Documentation <https://developer.code42.com/api/#operation/UserControllerV2_AddRiskFactors>`__
 
         Args:
             user_id (str or int): The userUid of the user whose risk factor tag(s) you want to update.
@@ -98,6 +105,7 @@ class DetectionListsClient(object):
 
     def remove_user_risk_tags(self, user_id, tags):
         """Remove one or more risk factor tags.
+        `Rest Documentation <https://developer.code42.com/api/#operation/UserControllerV2_RemoveRiskFactors>`__
 
         Args:
             user_id (str or int): The userUid of the user whose risk factor tag(s) needs you want to remove.
@@ -112,6 +120,7 @@ class DetectionListsClient(object):
 
     def add_user_cloud_alias(self, user_id, alias):
         """Add a cloud alias to a user.
+        `Rest Documentation <https://developer.code42.com/api/#operation/UserControllerV2_AddCloudUsernames>`__
 
         Args:
             user_id (str or int): The userUid of the user whose alias you want to update.
@@ -124,6 +133,7 @@ class DetectionListsClient(object):
 
     def remove_user_cloud_alias(self, user_id, alias):
         """Remove a cloud alias from a user.
+        `Rest Documentation <https://developer.code42.com/api/#operation/UserControllerV2_RemoveCloudUsernames>`__
 
         Args:
             user_id (str or int): The userUid of the user whose alias needs to be removed.
@@ -136,7 +146,7 @@ class DetectionListsClient(object):
 
     def refresh_user_scim_attributes(self, user_id):
         """Refresh SCIM attributes of a user.
-        `REST documentation <https://ecm-default.prod.ffs.us2.code42.com/svc/swagger/index.html?urls.primaryName=v2#/User/UserControllerV2_RefreshUser>`__
+        `Rest Documentation <https://developer.code42.com/api/#operation/UserControllerV2_RefreshUser>`__
 
         Args:
             user_id (str or int): The userUid of the user whose attributes you wish to refresh.
