@@ -1,6 +1,7 @@
 import re
 
 from py42._compat import str
+from py42.settings import debug
 
 
 class Py42Error(Exception):
@@ -54,7 +55,13 @@ class Py42HTTPError(Py42ResponseError):
     """A base custom class to manage all HTTP errors raised by an API endpoint."""
 
     def __init__(self, exception, message=None):
-        message = message or u"Failure in HTTP call {}".format(str(exception))
+        if not message:
+            response_content = "Response content: {}".format(exception.response.text)
+            message = u"Failure in HTTP call {}. {}".format(
+                str(exception), response_content
+            )
+            debug.logger.debug(message)
+
         super(Py42HTTPError, self).__init__(exception.response, message)
 
 
@@ -141,6 +148,15 @@ class Py42TooManyRequestsError(Py42HTTPError):
     """A wrapper to represent an HTTP 429 error."""
 
 
+class Py42OrgNotFoundError(Py42BadRequestError):
+    """An exception raised when a 400 HTTP error message indicates that an
+    organization was not found."""
+
+    def __init__(self, exception, org_uid):
+        msg = u"The organization with UID '{}' was not found.".format(org_uid)
+        super(Py42OrgNotFoundError, self).__init__(exception, msg)
+
+
 class Py42ActiveLegalHoldError(Py42BadRequestError):
     """An exception raised when attempting to deactivate a user or device that is in an
     active legal hold."""
@@ -180,7 +196,8 @@ class Py42LegalHoldCriteriaMissingError(Py42BadRequestError):
     def __init__(self, exception):
         super(Py42LegalHoldCriteriaMissingError, self).__init__(
             exception,
-            u"At least one criteria must be specified; hold_membership_uid, hold_uid, user_uid, or user.",
+            u"At least one criteria must be specified; legal_hold_membership_uid, "
+            u"legal_hold_uid, user_uid, or user.",
         )
 
 
@@ -211,6 +228,15 @@ class Py42UserAlreadyExistsError(Py42InternalServerError):
         super(Py42UserAlreadyExistsError, self).__init__(exception, message)
 
 
+class Py42UsernameMustBeEmailError(Py42InternalServerError):
+    """An exception raised when trying to set a non-email as a user's username
+    in a cloud environment."""
+
+    def __init__(self, exception):
+        message = u"Username must be an email address."
+        super(Py42UsernameMustBeEmailError, self).__init__(exception, message)
+
+
 class Py42CloudAliasLimitExceededError(Py42BadRequestError):
     """An Exception raised when trying to add a cloud alias to a user when that user
     already has the max amount of supported cloud aliases."""
@@ -259,7 +285,7 @@ class Py42UpdateClosedCaseError(Py42BadRequestError):
     """An error raised when trying to update a closed case."""
 
     def __init__(self, exception):
-        msg = "Cannot update a closed case."
+        msg = u"Cannot update a closed case."
         super(Py42UpdateClosedCaseError, self).__init__(exception, msg)
 
 
@@ -267,7 +293,9 @@ class Py42CaseNameExistsError(Py42BadRequestError):
     """An error raised when trying to create a case with a name that already exists."""
 
     def __init__(self, exception, case_name):
-        msg = "Case name '{}' already exists, please set another name".format(case_name)
+        msg = u"Case name '{}' already exists, please set another name".format(
+            case_name
+        )
         super(Py42CaseNameExistsError, self).__init__(exception, msg)
 
 
@@ -275,15 +303,23 @@ class Py42DescriptionLimitExceededError(Py42BadRequestError):
     """An error raised when description of a case exceeds the allowed char length limit."""
 
     def __init__(self, exception):
-        msg = "Description limit exceeded, max 250 characters allowed."
+        msg = u"Description limit exceeded, max 250 characters allowed."
         super(Py42DescriptionLimitExceededError, self).__init__(exception, msg)
 
 
+class Py42InvalidCaseUserError(Py42BadRequestError):
+    """An error raised when a case subject or assignee is not a valid user."""
+
+    def __init__(self, exception, user_field):
+        msg = u"The provided {} is not a valid user.".format(user_field)
+        super(Py42InvalidCaseUserError, self).__init__(exception, msg)
+
+
 class Py42CaseAlreadyHasEventError(Py42BadRequestError):
     """An error raised when event is already associated to the case."""
 
     def __init__(self, exception):
-        msg = "Event is already associated to the case."
+        msg = u"Event is already associated to the case."
         super(Py42CaseAlreadyHasEventError, self).__init__(exception, msg)
 
 
