@@ -12,16 +12,35 @@ class AlertService(BaseService):
 
     _CREATED_AT = u"CreatedAt"
     _RULE_METADATA = u"ruleMetadata"
+    _SEARCH_KEY = u"alerts"
 
     def __init__(self, connection, user_context):
         super(AlertService, self).__init__(connection)
         self._user_context = user_context
 
-    def search(self, query):
+    def search(self, query, page_num=1, page_size=None):
+        query.page_number = page_num - 1
+        if page_size:
+            query.page_size = page_size
         query = self._add_tenant_id_if_missing(query)
         uri = self._uri_prefix.format(u"query-alerts")
         return self._connection.post(uri, data=query)
 
+    def get_search_page(self, query, page_num, page_size):
+        query.page_number = page_num - 1
+        query.page_size = page_size
+        uri = self._uri_prefix.format(u"query-alerts")
+        query = self._add_tenant_id_if_missing(query)
+        return self._connection.post(uri, data=query)
+
+    def search_all_pages(self, query):
+        return get_all_pages(
+            self.get_search_page,
+            self._SEARCH_KEY,
+            query=query,
+            page_size=query.page_size,
+        )
+
     def get_details(self, alert_ids):
         if not isinstance(alert_ids, (list, tuple)):
             alert_ids = [alert_ids]
@@ -31,10 +50,9 @@ class AlertService(BaseService):
         results = self._connection.post(uri, json=data)
         return _convert_observation_json_strings_to_objects(results)
 
-    def update_state(self, state, alert_ids, note=""):
+    def update_state(self, state, alert_ids, note=None):
         if not isinstance(alert_ids, (list, tuple)):
             alert_ids = [alert_ids]
-        note = note or ""
         tenant_id = self._user_context.get_current_tenant_id()
         uri = self._uri_prefix.format(u"update-state")
         data = {
@@ -106,6 +124,23 @@ class AlertService(BaseService):
         )
         return next(results)
 
+    def update_note(self, alert_id, note):
+        tenant_id = self._user_context.get_current_tenant_id()
+        uri = self._uri_prefix.format(u"add-note")
+        data = {
+            u"tenantId": tenant_id,
+            u"alertId": alert_id,
+            u"note": note,
+        }
+        return self._connection.post(uri, json=data)
+
+    def get_aggregate_data(self, alert_id):
+        uri = self._uri_prefix.format(u"query-details-aggregate")
+        data = {
+            u"alertId": alert_id,
+        }
+        return self._connection.post(uri, json=data)
+
 
 def _convert_observation_json_strings_to_objects(results):
     for alert in results[u"alerts"]:
