@@ -36,11 +36,11 @@ class HighRiskEmployeeService(BaseService):
         return self._connection.post(uri, json=data)
 
     def add(self, user_id):
-        """Adds a user to the High Risk Employee detection list. Creates a detection list user
-        profile if one didn't already exist.
+        """Adds a user to the High Risk Employee detection list.
 
-        Raises a :class:`Py42BadRequestError` when a user already exists in the High Risk Employee
+        Raises a :class:`Py42UserAlreadyAddedError` when a user already exists in the High Risk Employee
         detection list.
+        `REST Documentation <https://developer.code42.com/api/#operation/HighRiskEmployeeControllerV2_AddEmployee>`__
 
         Args:
             user_id (str or int): The Code42 userUid of the user you want to add to the High Risk
@@ -49,18 +49,16 @@ class HighRiskEmployeeService(BaseService):
         Returns:
             :class:`py42.response.Py42Response`
         """
-        if self._user_profile_service.create_if_not_exists(user_id):
-            tenant_id = self._user_context.get_current_tenant_id()
-            try:
-                return self._add_high_risk_employee(tenant_id, user_id)
-            except Py42BadRequestError as err:
-                handle_user_already_added_error(
-                    err, user_id, u"high-risk-employee list"
-                )
-                raise
+        tenant_id = self._user_context.get_current_tenant_id()
+        try:
+            return self._add_high_risk_employee(tenant_id, user_id)
+        except Py42BadRequestError as err:
+            handle_user_already_added_error(err, user_id, u"high-risk-employee list")
+            raise
 
     def set_alerts_enabled(self, enabled=True):
         """Enables alerts.
+        `Rest Documentation <https://developer.code42.com/api/#operation/HighRiskEmployeeControllerV2_SetAlertState>`__
 
         Args:
             enabled (bool): Whether to enable alerts for all users.
@@ -77,6 +75,7 @@ class HighRiskEmployeeService(BaseService):
 
     def remove(self, user_id):
         """Removes a user from the High Risk Employee detection list.
+        `Rest Documentation <https://developer.code42.com/api/#operation/HighRiskEmployeeControllerV2_RemoveUser>`__
 
         Args:
             user_id (str or int): The Code42 userUid of the user you want to add to the High Risk
@@ -97,6 +96,7 @@ class HighRiskEmployeeService(BaseService):
 
     def get(self, user_id):
         """Gets user information.
+        `Rest Documentation <https://developer.code42.com/api/#operation/HighRiskEmployeeControllerV2_GetEmployee>`__
 
         Args:
             user_id (str or int): The Code42 userUid of the user has been added to the High Risk
@@ -120,6 +120,7 @@ class HighRiskEmployeeService(BaseService):
         page_size=_PAGE_SIZE,
     ):
         """Searches High Risk Employee list. Filter results by filter_type.
+        `Rest Documentation <https://developer.code42.com/api/#operation/HighRiskEmployeeControllerV2_Search>`__
 
         Args:
             filter_type (str, optional): ``EXFILTRATION_30_DAYS``, ``EXFILTRATION_24_HOURS``,
