@@ -1,6 +1,5 @@
 from py42.exceptions import Py42BadRequestError
 from py42.exceptions import Py42CloudAliasLimitExceededError
-from py42.exceptions import Py42NotFoundError
 from py42.services import BaseService
 
 
@@ -20,26 +19,6 @@ class DetectionListUserService(BaseService):
     def _make_uri(self, action):
         return u"{}{}".format(self._resource, action)
 
-    def create_if_not_exists(self, user_id):
-        """Find out whether the detection list profile exists for a given uid. If not,
-           if user_id is a valid uid of code42 user then it will create detection list profile
-           of the user.
-
-            Returns True when profile is created else raises error.
-
-            Args:
-                user_id (str or int): Uid of user.
-
-            Returns:
-                bool
-        """
-        try:
-            self.get_by_id(user_id)
-        except (Py42NotFoundError, Py42BadRequestError):
-            user = self._user_service.get_by_uid(user_id)
-            self.create(user[u"username"])
-        return True
-
     def create(self, username):
         """Create a detection list profile for a user.
 
