@@ -20,7 +20,7 @@ class PreservationDataService(BaseService):
         return self._connection.post(uri, json=data)
 
     def get_file_version_list(self, deviceGuid, file_md5, file_sha256, path):
-        params = "fileSHA256={}&fileMD5={}&deviceGuid={}&path={}"
+        params = u"fileSHA256={}&fileMD5={}&deviceGuid={}&path={}"
         params = params.format(file_sha256, file_md5, deviceGuid, quote(path))
         uri = u"/api/v1/FileVersionListing?{}".format(params)
         return self._connection.get(uri)
