@@ -2,7 +2,9 @@ from py42 import settings
 from py42._compat import quote
 from py42.exceptions import Py42BadRequestError
 from py42.exceptions import Py42InternalServerError
+from py42.exceptions import Py42OrgNotFoundError
 from py42.exceptions import Py42UserAlreadyExistsError
+from py42.exceptions import Py42UsernameMustBeEmailError
 from py42.services import BaseService
 from py42.services import handle_active_legal_hold_error
 from py42.services.util import get_all_pages
@@ -11,6 +13,7 @@ from py42.services.util import get_all_pages
 class UserService(BaseService):
     """A service for interacting with Code42 user APIs. Use the UserService to create and retrieve
     users. You can also use it to block and deactivate users.
+
     """
 
     def create_user(
@@ -57,10 +60,11 @@ class UserService(BaseService):
         except Py42InternalServerError as err:
             if u"USER_DUPLICATE" in err.response.text:
                 raise Py42UserAlreadyExistsError(err)
+            raise
 
     def get_by_id(self, user_id, **kwargs):
         """Gets the user with the given ID.
-        `REST Documentation <https://console.us.code42.com/apidocviewer/#User-get>`__
+        `Rest Documentation <https://developer.code42.com/api/#tag/User/paths/~1v1~1users~1{userId}/get>`__
 
         Args:
             user_id (int): An ID for a user.
@@ -73,7 +77,6 @@ class UserService(BaseService):
 
     def get_by_uid(self, user_uid, **kwargs):
         """Gets the user with the given UID.
-        `REST Documentation <https://console.us.code42.com/apidocviewer/#User-get>`__
 
         Args:
             user_uid (str): A UID for a user.
@@ -87,7 +90,6 @@ class UserService(BaseService):
 
     def get_by_username(self, username, **kwargs):
         """Gets the user with the given username.
-        `REST Documentation <https://console.us.code42.com/apidocviewer/#User-get>`__
 
         Args:
             username (str or unicode): A username for a user.
@@ -101,7 +103,6 @@ class UserService(BaseService):
 
     def get_current(self, **kwargs):
         """Gets the currently signed in user.
-        `REST Documentation <https://console.us.code42.com/apidocviewer/#User-get>`__
 
         Returns:
             :class:`py42.response.Py42Response`: A response containing the user.
@@ -121,7 +122,6 @@ class UserService(BaseService):
         **kwargs
     ):
         """Gets an individual page of users.
-        `REST Documentation <https://console.us.code42.com/apidocviewer/#User-get>`__
 
         Args:
             page_num (int): The page number to request.
@@ -152,14 +152,17 @@ class UserService(BaseService):
             q=q,
             **kwargs
         )
-
-        return self._connection.get(uri, params=params)
+        try:
+            return self._connection.get(uri, params=params)
+        except Py42BadRequestError as err:
+            if u"Organization was not found" in str(err.response.text):
+                raise Py42OrgNotFoundError(err, org_uid)
+            raise
 
     def get_all(
         self, active=None, email=None, org_uid=None, role_id=None, q=None, **kwargs
     ):
         """Gets all users.
-        `REST Documentation <https://console.us.code42.com/apidocviewer/#User-get>`__
 
         Args:
             active (bool, optional): True gets active users only,
@@ -282,7 +285,7 @@ class UserService(BaseService):
     def get_available_roles(self):
         """Report the list of roles that are available for the authenticated user to
         assign to other users.
-        `V4 REST Documentation <https://console.us.code42.com/swagger/#/role/Role_View>`__
+        `REST Documentation <https://console.us.code42.com/swagger/?urls.primaryName=v4#/role/Role_View>`__
 
         Returns:
             :class:`py42.response.Py42Response`
@@ -320,7 +323,7 @@ class UserService(BaseService):
 
     def remove_role(self, user_id, role_name):
         """Removes a role from a user.
-        REST Documentation <https://console.us.code42.com/apidocviewer/#UserRole-delete>`__
+        `REST Documentation <https://console.us.code42.com/apidocviewer/#UserRole-delete>`__
 
         Args:
             user_id (int): An ID for a user.
@@ -334,3 +337,48 @@ class UserService(BaseService):
         role_name = quote(role_name)
         uri = u"/api/UserRole?userId={}&roleName={}".format(user_id, role_name)
         return self._connection.delete(uri)
+
+    def update_user(
+        self,
+        user_uid,
+        username=None,
+        email=None,
+        password=None,
+        first_name=None,
+        last_name=None,
+        notes=None,
+        archive_size_quota_bytes=None,
+    ):
+        """Updates an existing user.
+        `REST Documentation <https://console.us.code42.com/apidocviewer/#User-put>`__
+
+        Args:
+            user_uid (str or int): A Code42 user UID.
+            username (str, optional): The username to which the user's username will be changed. Defaults to None.
+            email (str, optional): The email to which the user's email will be changed. Defaults to None.
+            password (str, optional): The password to which the user's password will be changed. Defaults to None.
+            first_name (str, optional): The first name to which the user's first name will be changed. Defaults to None.
+            last_name (str, optional): The last name to which the user's last name will be changed. Defaults to None.
+            notes (str, optional): Descriptive information about the user. Defaults to None.
+            archive_size_quota_bytes (int, optional): The quota in bytes that limits the user's archive size. Defaults to None.
+
+        Returns:
+            :class:`py42.response.Py42Response`
+        """
+
+        uri = u"/api/User/{}?idType=uid".format(user_uid)
+        data = {
+            u"username": username,
+            u"email": email,
+            u"password": password,
+            u"firstName": first_name,
+            u"lastName": last_name,
+            u"notes": notes,
+            u"quotaInBytes": archive_size_quota_bytes,
+        }
+        try:
+            return self._connection.put(uri, json=data)
+        except Py42InternalServerError as err:
+            if u"USERNAME_NOT_AN_EMAIL" in str(err.response.text):
+                raise Py42UsernameMustBeEmailError(err)
+            raise
